OC.L10N.register(
    "spreed",
    {
    "Guest" : "Invitato",
    "Everyone" : "Totos",
    "Save changes" : "Salveguardar cambios",
    "None" : "Nulle",
    "User" : "User",
    "Users" : "Usatores",
    "Name" : "Nomine",
    "Language" : "Lingua",
    "Country" : "Pais",
    "Pending" : "Pendente",
    "Error" : "Error",
    "Saved" : "Salveguardate",
    "UDP only" : "solo UDP",
    "TCP only" : "solo TCP",
    "Copy link" : "Copiar ligamine",
    "Dismiss" : "Dimitter",
    "You" : "Tu",
    "Favorite" : "Favorite",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Loading",
    "Groups" : "Gruppos",
    "Password protect" : "Proteger per contrasigno",
    "Back" : "Retro",
    "Close" : "Clauder",
    "Reply" : "Responder",
    "Today" : "Hodie",
    "Yesterday" : "Heri",
    "guest" : "hospite",
    "Add users or groups" : "Add users or groups",
    "Settings" : "Configurationes",
    "Edit" : "Modificar",
    "Share link" : "Compartir ligamine",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Access to microphone & camera is only possible with HTTPS" : "Accesso al microphono e al camera solmente es possibile per HTTPS",
    "Access to microphone & camera was denied" : "Accesso al microphono e al camera solmente esseva negate",
    "WebRTC is not supported in your browser" : "WebRTC non es supportate per tu navigator",
    "Please use a different browser like Firefox or Chrome" : "Per favor, usa un navigator differente tal como Firefox o Chrome",
    "Error while accessing microphone & camera" : "Error durante accesso a microphono e camera",
    "The password is wrong. Try again." : "Le contrasigno es incorrecte. Tenta de novo.",
    "Password" : "Contrasigno",
    "TURN server" : "servitor TURN",
    "Android app" : "Application Android",
    "iOS app" : "Application iOS",
    "Copy" : "Copiar",
    "Copied!" : "Copiate!",
    "Not supported!" : "Non supportate!",
    "Press ⌘-C to copy." : "Pulsa ⌘-C pro copiar.",
    "Press Ctrl-C to copy." : "Pulsa Ctrl-C pro copiar.",
    "Cancel" : "Cancellar",
    "Change password" : "Cambiar contrasigno",
    "Rename" : "Renominar",
    "Send" : "Inviar",
    "Share" : "Compartir",
    "Error while sharing" : "Error al compartir",
    "WebRTC is not supported in your browser :-/" : "WebRTC non es supportate per tu navigator  :-/",
    "Favorited" : "Favorite",
    "Contacts" : "Contactos"
},
"nplurals=2; plural=(n != 1);");
